==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/client/flywheel/lib/model/baked/ModelPartCommandRendererHelper.java <==
package com.zurrtum.create.client.flywheel.lib.model.baked;

import java.util.List;
import java.util.Map;
import net.minecraft.class_1088;
import net.minecraft.class_11661;
import net.minecraft.class_11788;
import net.minecraft.class_11793;
import net.minecraft.class_1921;
import net.minecraft.class_4583;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_918;

public class ModelPartCommandRendererHelper {
    public static void render(
        class_4587 matrices,
        class_11788 queue,
        class_4597 vertexConsumers,
        class_4597 outlineVertexConsumerProvider,
        class_4597 immediate
    ) {
        class_11793.class_12049 commands = queue.method_73521();

        for (Map.Entry<class_1921, List<class_11661.class_11789>> entry : commands.field_62985.entrySet()) {
            class_1921 renderLayer = entry.getKey();
            List<class_11661.class_11789> list = entry.getValue();
            class_4588 vertexConsumer = vertexConsumers.method_73477(renderLayer);

            for (class_11661.class_11789 modelPartCommand : list) {
                class_4588 vertexConsumer2;
                if (modelPartCommand.comp_4647() != null) {
                    if (modelPartCommand.comp_4649()) {
                        vertexConsumer2 = modelPartCommand.comp_4647()
                            .method_24108(class_918.method_23181(vertexConsumers, renderLayer, modelPartCommand.comp_4648(), true));
                    } else {
                        vertexConsumer2 = modelPartCommand.comp_4647().method_24108(vertexConsumer);
                    }
                } else if (modelPartCommand.comp_4649()) {
                    vertexConsumer2 = class_918.method_23181(vertexConsumers, renderLayer, modelPartCommand.comp_4648(), true);
                } else {
                    vertexConsumer2 = vertexConsumer;
                }

                matrices.method_23760().method_66521(modelPartCommand.comp_4643());
                modelPartCommand.comp_4644().method_22699(
                    matrices,
                    vertexConsumer2,
                    modelPartCommand.comp_4645(),
                    modelPartCommand.comp_4646(),
                    modelPartCommand.comp_4650()
                );
                if (modelPartCommand.comp_4940() != 0 && (renderLayer.method_23289().isPresent() || renderLayer.method_24295())) {
                    class_4588 vertexConsumer3 = CustomCommandRendererHelper.getOutlineBuffer(
                        outlineVertexConsumerProvider,
                        renderLayer,
                        modelPartCommand.comp_4940()
                    );
                    if (vertexConsumer3 != null) {
                        if (modelPartCommand.comp_4647() != null) {
                            vertexConsumer3 = modelPartCommand.comp_4647().method_24108(vertexConsumer3);
                        }
                        modelPartCommand.comp_4644().method_22699(
                            matrices,
                            vertexConsumer3,
                            modelPartCommand.comp_4645(),
                            modelPartCommand.comp_4646(),
                            modelPartCommand.comp_4650()
                        );
                    }
                }

                if (modelPartCommand.comp_4760() != null) {
                    class_4588 vertexConsumer3 = new class_4583(
                        immediate.method_73477(class_1088.field_21772.get(modelPartCommand.comp_4760().comp_4656())),
                        modelPartCommand.comp_4760().comp_4657(),
                        1.0F
                    );
                    modelPartCommand.comp_4644().method_22699(
                        matrices,
                        vertexConsumer3,
                        modelPartCommand.comp_4645(),
                        modelPartCommand.comp_4646(),
                        modelPartCommand.comp_4650()
                    );
                }
            }
        }
    }
}

==> create-fly-6.0.8-1.21.10-2-sources.jar: com/zurrtum/create/client/flywheel/lib/model/baked/ModelPartCommandRendererHelper.java <==
package com.zurrtum.create.client.flywheel.lib.model.baked;

import java.util.List;
import java.util.Map;
import net.minecraft.class_1088;
import net.minecraft.class_11661;
import net.minecraft.class_11788;
import net.minecraft.class_11793;
import net.minecraft.class_1921;
import net.minecraft.class_4583;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_918;

public class ModelPartCommandRendererHelper {
    public static void render(
        class_4587 matrices,
        class_11788 queue,
        class_4597 vertexConsumers,
        class_4597 outlineVertexConsumerProvider,
        class_4597 immediate
    ) {
        class_11793.class_12049 commands = queue.method_73521();

        for (Map.Entry<class_1921, List<class_11661.class_11789>> entry : commands.field_62985.entrySet()) {
            class_1921 renderLayer = entry.getKey();
            List<class_11661.class_11789> list = entry.getValue();
            class_4588 vertexConsumer = vertexConsumers.method_73477(renderLayer);

            for (class_11661.class_11789 modelPartCommand : list) {
                class_4588 vertexConsumer2;
                if (modelPartCommand.comp_4647() != null) {
                    if (modelPartCommand.comp_4649()) {
                        vertexConsumer2 = modelPartCommand.comp_4647()
                            .method_24108(class_918.method_23181(
                                vertexConsumers,
                                renderLayer,
                                modelPartCommand.comp_4648(),
                                true
                            ));
                    } else {
                        vertexConsumer2 = modelPartCommand.comp_4647().method_24108(vertexConsumer);
                    }
                } else if (modelPartCommand.comp_4649()) {
                    vertexConsumer2 = class_918.method_23181(vertexConsumers, renderLayer, modelPartCommand.comp_4648(), true);
                } else {
                    vertexConsumer2 = vertexConsumer;
                }

                matrices.method_23760().method_66521(modelPartCommand.comp_4643());
                modelPartCommand.comp_4644().method_22699(
                    matrices,
                    vertexConsumer2,
                    modelPartCommand.comp_4645(),
                    modelPartCommand.comp_4646(),
                    modelPartCommand.comp_4650()
                );
                if (modelPartCommand.comp_4940() != 0 && (renderLayer.method_23289().isPresent() || renderLayer.method_24295())) {
                    class_4588 vertexConsumer3 = CustomCommandRendererHelper.getOutlineBuffer(
                        outlineVertexConsumerProvider,
                        renderLayer,
                        modelPartCommand.comp_4940()
                    );
                    if (vertexConsumer3 != null) {
                        if (modelPartCommand.comp_4647() != null) {
                            vertexConsumer3 = modelPartCommand.comp_4647().method_24108(vertexConsumer3);
                        }
                        modelPartCommand.comp_4644().method_22699(
                            matrices,
                            vertexConsumer3,
                            modelPartCommand.comp_4645(),
                            modelPartCommand.comp_4646(),
                            modelPartCommand.comp_4650()
                        );
                    }
                }

                if (modelPartCommand.comp_4760() != null) {
                    class_4588 vertexConsumer3 = new class_4583(
                        immediate.method_73477(class_1088.field_21772.get(modelPartCommand.comp_4760().comp_4656())),
                        modelPartCommand.comp_4760().comp_4657(),
                        1.0F
                    );
                    modelPartCommand.comp_4644().method_22699(
                        matrices,
                        vertexConsumer3,
                        modelPartCommand.comp_4645(),
                        modelPartCommand.comp_4646(),
                        modelPartCommand.comp_4650()
                    );
                }
            }
        }
    }
}
